CurlBuilder class
Builds a curl command from RequestOptions.
Call this from an HttpClientAdapter, not from an interceptor's
Interceptor.onRequest: by adapter time Dio has already applied
interceptor headers (cookies, auth) and computed content-length.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromRequestOptions(
RequestOptions options) → String