CurlCapturingAdapter class

Wraps Dio's platform HttpClientAdapter and builds the final curl right before the request is sent — the latest point where all Dio headers (including content-length) are available.

Constructors

CurlCapturingAdapter(HttpClientAdapter _inner)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close({bool force = false}) → void
Close the current adapter and its inner clients or requests.
fetch(RequestOptions options, Stream<Uint8List>? requestStream, Future<void>? cancelFuture) Future<ResponseBody>
Implement this method to make real HTTP requests.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited