ExceptionMonitoringParams class
Properties
-
errorMessage
→ String?
-
String representation of exception, for convenience when reporting.
final
-
exception
→ Object
-
The caught runtime exception (parsing, casting, model conversion, etc.).
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
requestUrl
→ String?
-
Relative or absolute request URL being processed when the error occurred.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stackTrace
→ StackTrace
-
Stack trace captured with the exception.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited