SecretPatterns class
Predefined secret patterns
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
accessible
→ const List<
KnockType> - Double-tap + long-press (for accessibility)
-
morseSOS
→ const List<
KnockType> - Morse Code SOS (· · · — — — · · ·)
-
shaveAndHaircut
→ const List<
KnockType> - "Shave and a Haircut" (tap-tap-hold)
-
tripleLongPress
→ const List<
KnockType> - Triple long-press (default)